@@ -17,10 +17,12 @@ def main():
     exit()
 
   if(command == 'serve'):
-    serve_local_model()
+    serve_local_model(sys.argv[2])
 
   if(command == 'init'):
     os.system('git clone https://github.com/inferrd/custom-environment-example')
+    os.system('cd custom-environment-example')
+    os.system('python -m pip install -r requirements.txt')
 
   if(command == 'auth'):
     api_key = sys.argv[2]
