@@ -2,9 +2,7 @@ import os
 import flask
 import sys
 
-def serve_local_model():
-  print('> Adding this directory to python path')
-  print(os.getcwd())
+def serve_local_model(port = 3005):
   sys.path.insert(0, os.getcwd())
   # check that files exist
   print('> Loading predictor.py...')
@@ -45,5 +43,5 @@ def serve_local_model():
     return flask.jsonify(data)
 
   # start the flask app, allow remote connections
-  print('> Local server is running on port 3005')
-  app.run(host='0.0.0.0', port=3005)
\ No newline at end of file
+  print('> Local server is running on port ' + str(port))
+  app.run(host='0.0.0.0', port=port)
\ No newline at end of file
